.. image:: https://travis-ci.org/rgalanakis/goless.svg?branch=master
    :target: https://travis-ci.org/rgalanakis/goless
    :alt: build status
    :align: right

.. image:: https://img.shields.io/coveralls/rgalanakis/goless.svg
    :target: https://coveralls.io/r/rgalanakis/goless
    :alt: coverage status
    :align: right

goless
======

The **goless** library provides **Go** programming language
semantics built on top of **gevent**, **PyPy**, or **Stackless Python**.
It works with PyPy, CPython, and Stackless Python interpreters.

**goless** has extensive documentation and examples.
See <https://goless.readthedocs.org/> for more information.
